;; Generated package description from prefixed-core.el  -*- no-byte-compile: t -*-
(define-package "prefixed-core" "0.0.20200702.214920" "Rename core functions for a better structured namespace" 'nil :url "https://elpa.gnu.org/packages/prefixed-core.html" :authors '(("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("Stefan Monnier" . "monnier@iro.umontreal.ca"))
